@@ -1,5 +1,4 @@
 __all__ = (
-    'MotionEventAlreadyEndedError',
     'anim_attrs',
     'anim_attrs_abbr',
     'anim_with_dt',
@@ -21,6 +20,7 @@ __all__ = (
     'run_in_thread',
     'sleep',
     'sleep_free',
+    'sleep_freq',
     'smooth_attr',
     'suppress_event',
     'sync_attr',
@@ -29,15 +29,12 @@ __all__ = (
 )
 
 from asyncgui import *
-from ._exceptions import MotionEventAlreadyEndedError
-from ._sleep import sleep, sleep_free, repeat_sleeping, move_on_after
-from ._event import event, event_freq
+from ._sleep import sleep, sleep_free, repeat_sleeping, move_on_after, n_frames, sleep_freq
+from ._event import event, event_freq, suppress_event, rest_of_touch_events
 from ._anim_with_xxx import anim_with_dt, anim_with_et, anim_with_ratio, anim_with_dt_et, anim_with_dt_et_ratio
 from ._anim_attrs import anim_attrs, anim_attrs_abbr
 from ._interpolate import interpolate, interpolate_seq, fade_transition
-from ._touch import rest_of_touch_events
 from ._threading import run_in_executor, run_in_thread
-from ._n_frames import n_frames
-from ._utils import transform, suppress_event, sync_attr, sync_attrs
+from ._etc import transform, sync_attr, sync_attrs
 from ._managed_start import managed_start
 from ._smooth_attr import smooth_attr
